package org.jboss.as.integration.hornetq.deployers;

import org.hornetq.jms.server.config.JMSConfiguration;
import org.jboss.as.integration.hornetq.deployers.pojo.HornetQCoreDeployment;
import org.jboss.beans.metadata.spi.BeanMetaData;
import org.jboss.deployers.spi.DeploymentException;
import org.jboss.deployers.spi.deployer.helpers.AbstractSimpleRealDeployer;
import org.jboss.deployers.structure.spi.DeploymentUnit;
import org.jboss.metadata.ejb.jboss.JBossMetaData;

/**
 * In a regular flow HornetQJMSParserDeployer will parer hornetq-jms.xml and it
 * will jump-start the deployment for JMSConfiguration.class. This deployer will
 * then be called directly by the VFS Deployment Framework, as the Input object
 * for this is a JMSConfiguration class.
 * 
 * In an alternate flow, other deployers (e.g. TorqueBox) may install a
 * JMSConfiguration object directly and this deployer will take over without the
 * need of a real XML file
 * 
 * @author <mailto:clebert.suconic@jboss.org">Clebert Suconic</a>
 * 
 */
public class HornetQJMSRealDeployer extends AbstractSimpleRealDeployer<JMSConfiguration>
{
   public HornetQJMSRealDeployer()
   {
      super(JMSConfiguration.class);

      // This is just to guarantee the order. The CoreDeployments should happen before
      addInput(HornetQCoreDeployment.class);
      // This is just to guarantee the order. JBossMetaData deployment should happen before
      addInput(JBossMetaData.class);

      addOutput(BeanMetaData.class);
   }
   
   @Override
   public void deploy(DeploymentUnit unit, JMSConfiguration mainConfig) throws DeploymentException
   {
      if (log.isTraceEnabled())
      {
         log.trace("Deploying unit " + unit + " with config " + mainConfig);
      }
      DeploymentFactory.getInstance().deployJMS(unit, mainConfig);
   }
   

}
